@@ -1,3 +1,3 @@
 if(getRversion() >= "2.15.1")
     utils::globalVariables(c("gpr","dS","alpha","epsilon",
-                             "stabilize","type","lambda"))
+                             "stabilize","type","lambda","x"))
